@@ -307,6 +307,9 @@ class IPv4Obj(object):
             )
             raise AttributeError(errmsg)
 
+    def __ne__(self, val):
+        return not self.__eq__(val)
+
     def __gt__(self, val):
         try:
             for obj in [self, val]:
@@ -732,6 +735,9 @@ class IPv6Obj(object):
             )
             raise ValueError(errmsg)
 
+    def __ne__(self, val):
+        return not self.__eq__(val)
+
     def __gt__(self, val):
         try:
             for obj in [self, val]:
